module.exports={A:{A:{"2":"nB","8":"J D E F A","164":"B"},B:{"1":"P Q R U V W X Y Z a b c d e S f H","513":"C K L G M N O"},C:{"1":"0 1 2 3 4 5 6 7 8 9 w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","8":"oB eB I g J D E F A B C K L G M N O h i j k l m n o p q r s t pB qB","66":"u v"},D:{"1":"0 1 2 3 4 5 6 7 8 9 z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","8":"I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y"},E:{"1":"B C K L G cB dB yB zB 0B 1B","8":"I g J D tB jB uB vB","289":"E F A wB xB kB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","8":"F B C G M N O h i j k l 2B 3B 4B 5B cB lB 6B dB"},G:{"1":"GC HC IC JC KC LC MC NC OC PC QC","8":"jB 7B mB 8B 9B AC","289":"E BC CC DC EC FC"},H:{"2":"RC"},I:{"1":"H","8":"eB I SC TC UC VC mB WC XC"},J:{"8":"D A"},K:{"1":"T","8":"A B C cB lB dB"},L:{"1":"H"},M:{"1":"S"},N:{"8":"A","164":"B"},O:{"1":"YC"},P:{"1":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"1":"jC"},R:{"1":"kC"},S:{"1":"lC"}},B:2,C:"Web Cryptography"};
