module.exports={A:{A:{"2":"J D E nB","2561":"A B","2692":"F"},B:{"1":"P Q R U V W X Y Z a b c d e S f H","2561":"C K L G M N O"},C:{"1":"BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","16":"oB","1537":"0 1 2 3 4 5 6 7 8 9 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB qB","1796":"eB pB"},D:{"1":"PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","16":"I g J D E F A B C K L","1025":"0 1 2 3 4 5 6 7 8 9 x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB","1537":"G M N O h i j k l m n o p q r s t u v w"},E:{"1":"L G yB zB 0B 1B","16":"I g J tB jB","1025":"D E F A B C vB wB xB kB cB","1537":"uB","4097":"K dB"},F:{"1":"EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB dB","16":"F B C 2B 3B 4B 5B cB lB","260":"6B","1025":"0 1 2 3 4 5 6 7 8 9 k l m n o p q r s t u v w x y z AB BB CB DB","1537":"G M N O h i j"},G:{"16":"jB 7B mB","1025":"E BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC","1537":"8B 9B AC"},H:{"2":"RC"},I:{"16":"SC TC","1025":"H XC","1537":"eB I UC VC mB WC"},J:{"1025":"A","1537":"D"},K:{"1":"A B C cB lB dB","1025":"T"},L:{"1":"H"},M:{"1537":"S"},N:{"2561":"A B"},O:{"1537":"YC"},P:{"1025":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"1025":"jC"},R:{"1025":"kC"},S:{"1537":"lC"}},B:1,C:"input event"};
