module.exports={A:{A:{"2":"J D E F A B nB"},B:{"2":"C K L G M N O P Q R U V W X Y Z a b c d e S f H"},C:{"1":"UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","2":"0 1 2 3 4 5 6 7 8 9 oB eB I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB pB qB"},D:{"2":"0 1 2 3 4 5 6 7 8 9 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB"},E:{"2":"I g J D E F A B C K L G tB jB uB vB wB xB kB cB dB yB zB 0B 1B"},F:{"2":"0 1 2 3 4 5 6 7 8 9 F B C G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB 2B 3B 4B 5B cB lB 6B dB"},G:{"2":"E jB 7B mB 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC"},H:{"2":"RC"},I:{"2":"eB I H SC TC UC VC mB WC XC"},J:{"2":"D A"},K:{"2":"A B C T cB lB dB"},L:{"2":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"2":"YC"},P:{"2":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"2":"jC"},R:{"2":"kC"},S:{"2":"lC"}},B:5,C:"CSS Subgrid"};
