module.exports={A:{A:{"2":"J D E F A B nB"},B:{"1":"a b c d e S f H","2":"C K L G M N O","2052":"Y Z","3588":"P Q R U V W X"},C:{"1":"3 4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","2":"oB","164":"0 1 2 eB I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z pB qB"},D:{"1":"a b c d e S f H iB rB sB","292":"0 1 2 3 4 5 6 7 8 9 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB","2052":"Y Z","3588":"SB TB UB VB WB XB YB ZB aB bB P Q R U V W X"},E:{"1":"G 0B 1B","292":"I g J D E F A B C tB jB uB vB wB xB kB cB","2052":"zB","3588":"K L dB yB"},F:{"1":"ZB aB bB P Q R hB","2":"F B C 2B 3B 4B 5B cB lB 6B dB","292":"0 1 2 3 4 5 6 7 8 9 G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB","2052":"XB YB","3588":"IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB"},G:{"1":"QC","292":"E jB 7B mB 8B 9B AC BC CC DC EC FC GC HC IC","2052":"PC","3588":"JC KC LC MC NC OC"},H:{"2":"RC"},I:{"1":"H","292":"eB I SC TC UC VC mB WC XC"},J:{"292":"D A"},K:{"1":"T","2":"A B C cB lB dB"},L:{"1":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"292":"YC"},P:{"1":"iC","292":"I ZC aC bC cC dC","3588":"kB eC fC gC hC"},Q:{"3588":"jC"},R:{"3588":"kC"},S:{"3588":"lC"}},B:5,C:"CSS Logical Properties"};
