module.exports={A:{A:{"2":"nB","8":"J D E F A","129":"B"},B:{"1":"P Q R U V W X Y Z a b c d e S f H","129":"C K L G M N O"},C:{"1":"0 1 2 3 4 5 6 7 8 9 m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","2":"oB eB pB qB","129":"I g J D E F A B C K L G M N O h i j k l"},D:{"1":"0 1 2 3 4 5 6 7 8 9 v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","2":"I g J D","129":"E F A B C K L G M N O h i j k l m n o p q r s t u"},E:{"1":"E F A B C K L G xB kB cB dB yB zB 0B 1B","2":"I g tB jB","129":"J D uB vB wB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","2":"F B 2B 3B 4B 5B cB lB 6B","129":"C G M N O dB"},G:{"1":"E BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC","2":"jB 7B mB 8B 9B AC"},H:{"2":"RC"},I:{"1":"H","2":"eB I SC TC UC VC mB WC XC"},J:{"1":"A","2":"D"},K:{"1":"C T dB","2":"A B cB lB"},L:{"1":"H"},M:{"1":"S"},N:{"8":"A","129":"B"},O:{"129":"YC"},P:{"1":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"1":"jC"},R:{"1":"kC"},S:{"129":"lC"}},B:6,C:"WebGL - 3D Canvas graphics"};
