module.exports={A:{A:{"2":"J D E F A nB","2052":"B"},B:{"1":"C K L G M N O P Q R U V W X Y Z a b c d e S f H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","132":"oB eB I g J D E F A B C pB qB","260":"K L G M N O h i j k l m n o p q r s t u v w x"},D:{"1":"BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","260":"I g J D E F A B C K L G M N O h i","772":"0 1 2 j k l m n o p q r s t u v w x y z","1028":"3 4 5 6 7 8 9 AB"},E:{"1":"B C K L G cB dB yB zB 0B 1B","260":"I g A tB jB kB","772":"J D E F uB vB wB xB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","2":"F 2B","132":"B 3B 4B 5B cB lB","644":"C 6B dB","772":"G M N O h i j k l m n o p","1028":"q r s t u v w x"},G:{"1":"GC HC IC JC KC LC MC NC OC PC QC","260":"jB 7B mB EC FC","772":"E 8B 9B AC BC CC DC"},H:{"644":"RC"},I:{"1":"H","16":"SC TC","260":"UC","772":"eB I VC mB WC XC"},J:{"772":"D A"},K:{"1":"T","132":"A B cB lB","644":"C dB"},L:{"1":"H"},M:{"1":"S"},N:{"1":"B","2":"A"},O:{"1":"YC"},P:{"1":"ZC aC bC cC dC kB eC fC gC hC iC","1028":"I"},Q:{"1":"jC"},R:{"1028":"kC"},S:{"1":"lC"}},B:6,C:"const"};
