module.exports={A:{A:{"1":"A B","2":"J D E F nB"},B:{"1":"P Q R U V W X Y Z a b c d e S f H","2":"C K L G M N O"},C:{"1":"0 1 2 3 4 5 6 7 8 9 z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","2":"oB eB pB qB","132":"I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y"},D:{"1":"0 1 2 3 4 5 6 7 8 9 o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","2":"I","16":"g J D E j k l m n","132":"F A B C K L G M N O h i"},E:{"1":"C K L G cB dB yB zB 0B 1B","2":"I g tB jB uB","132":"J D E F A B vB wB xB kB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","2":"F B C 2B 3B 4B 5B cB lB 6B dB"},G:{"2":"9B AC","132":"E BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC","514":"jB 7B mB 8B"},H:{"2":"RC"},I:{"2":"SC TC UC","260":"eB I VC mB","514":"H WC XC"},J:{"132":"A","260":"D"},K:{"2":"A B C cB lB dB","514":"T"},L:{"260":"H"},M:{"2":"S"},N:{"514":"A","1028":"B"},O:{"2":"YC"},P:{"260":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"260":"jC"},R:{"260":"kC"},S:{"1":"lC"}},B:1,C:"accept attribute for file input"};
