module.exports={A:{A:{"2":"F A B nB","8":"J D E"},B:{"2":"C K L G M N O P Q R U V W X Y Z a b c d e S f H"},C:{"2":"0 1 2 3 4 5 6 7 8 9 oB eB I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB pB qB"},D:{"1":"I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z","2":"DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","130":"0 1 2 3 4 5 6 7 8 9 AB BB CB"},E:{"1":"I g J D E F A B C K L G jB uB vB wB xB kB cB dB yB zB 0B 1B","2":"tB"},F:{"1":"F B C G M N O h i j k l m 2B 3B 4B 5B cB lB 6B dB","2":"0 1 2 3 4 5 6 7 8 9 z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","130":"n o p q r s t u v w x y"},G:{"1":"E jB 7B mB 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC"},H:{"258":"RC"},I:{"1":"eB I VC mB WC XC","2":"H SC TC UC"},J:{"1":"D A"},K:{"1":"A B C cB lB dB","2":"T"},L:{"130":"H"},M:{"2":"S"},N:{"2":"A B"},O:{"2":"YC"},P:{"1":"I","130":"ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"2":"jC"},R:{"130":"kC"},S:{"2":"lC"}},B:2,C:"SVG fonts"};
