module.exports={A:{A:{"2":"J D E F A B nB"},B:{"1":"P Q R U V W X Y Z a b c d e S f H","2":"C","260":"K L G M N O"},C:{"1":"CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","2":"oB eB I g J D E F A B C K L G M N O h i j k l m n o p q pB qB","516":"0 1 2 3 4 5 6 7 8 9 r s t u v w x y z AB BB"},D:{"1":"FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","2":"I","16":"g J D E F A B C K L","260":"EB","772":"0 1 2 3 4 5 6 7 8 9 G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB"},E:{"1":"B C K L G kB cB dB yB zB 0B 1B","2":"I tB jB","16":"g","772":"J D E F A uB vB wB xB"},F:{"1":"2 3 4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","16":"F 2B","260":"1 B C 3B 4B 5B cB lB 6B dB","772":"0 G M N O h i j k l m n o p q r s t u v w x y z"},G:{"1":"FC GC HC IC JC KC LC MC NC OC PC QC","2":"jB 7B mB","772":"E 8B 9B AC BC CC DC EC"},H:{"132":"RC"},I:{"1":"H","2":"eB SC TC UC","260":"I VC mB WC XC"},J:{"2":"D","260":"A"},K:{"1":"T","260":"A B C cB lB dB"},L:{"1":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"1":"YC"},P:{"1":"ZC aC bC cC dC kB eC fC gC hC iC","260":"I"},Q:{"1":"jC"},R:{"1":"kC"},S:{"516":"lC"}},B:5,C:":in-range and :out-of-range CSS pseudo-classes"};
