module.exports={A:{A:{"1":"F A B","2":"J D E nB"},B:{"1":"C K L G M N O P Q R U V W X Y Z a b c d e S f H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","2":"oB eB I g J D E F A B C K L pB qB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","132":"I g J D E F A B C K L G M N O h i j k l m n o p q r"},E:{"1":"D E F A B C K L G vB wB xB kB cB dB yB zB 0B 1B","16":"J tB jB","132":"I g uB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB dB","2":"F B 2B 3B 4B 5B cB lB 6B","16":"C","132":"G M"},G:{"1":"E BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC","16":"jB 7B mB","132":"8B 9B AC"},H:{"2":"RC"},I:{"1":"H WC XC","16":"SC TC","132":"eB I UC VC mB"},J:{"132":"D A"},K:{"1":"T dB","2":"A B cB lB","16":"C"},L:{"1":"H"},M:{"1":"S"},N:{"1":"A B"},O:{"1":"YC"},P:{"1":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"1":"jC"},R:{"1":"kC"},S:{"1":"lC"}},B:5,C:"KeyboardEvent.location"};
