module.exports={A:{A:{"2":"nB","4":"A B","8":"J D E F"},B:{"1":"M N O P Q R U V W X Y Z a b c d e S f H","4":"C K L G"},C:{"4":"0 1 2 3 4 5 6 7 8 9 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","8":"oB eB pB qB"},D:{"1":"gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","4":"0 1 2 3 4 5 6 7 8 9 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB"},E:{"4":"I g J D E F A B C K L G uB vB wB xB kB cB dB yB zB 0B 1B","8":"tB jB"},F:{"1":"F B C EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB 2B 3B 4B 5B cB lB 6B dB","4":"0 1 2 3 4 5 6 7 8 9 G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB"},G:{"2":"jB","4":"E 7B mB 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC"},H:{"2":"RC"},I:{"1":"H","2":"eB I SC TC UC VC mB","4":"WC XC"},J:{"2":"D","4":"A"},K:{"1":"A B C T cB lB dB"},L:{"1":"H"},M:{"4":"S"},N:{"4":"A B"},O:{"1":"YC"},P:{"1":"cC dC kB eC fC gC hC iC","4":"I ZC aC bC"},Q:{"1":"jC"},R:{"4":"kC"},S:{"4":"lC"}},B:1,C:"HTML5 form features"};
