module.exports={A:{A:{"1":"F A B","2":"nB","8":"J D E"},B:{"1":"C K L G M N O","129":"P Q R U V W X Y Z a b c d e S f H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB pB qB","8":"oB eB","129":"HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB","4":"I","129":"CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB"},E:{"1":"g J D E F B C K L G uB vB wB xB kB cB dB yB zB 0B 1B","8":"I tB jB","129":"A"},F:{"1":"0 B C M N O h i j k l m n o p q r s t u v w x y z 5B cB lB 6B dB","2":"F G 2B","8":"3B 4B","129":"1 2 3 4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB"},G:{"1":"E jB 7B mB 8B 9B AC BC CC DC","129":"EC FC GC HC IC JC KC LC MC NC OC PC QC"},H:{"2":"RC"},I:{"1":"eB I SC TC UC VC mB WC XC","129":"H"},J:{"1":"D A"},K:{"1":"B C cB lB dB","8":"A","129":"T"},L:{"129":"H"},M:{"129":"S"},N:{"1":"A B"},O:{"1":"YC"},P:{"1":"I","129":"ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"129":"jC"},R:{"129":"kC"},S:{"1":"lC"}},B:2,C:"Geolocation"};
