module.exports={A:{A:{"2":"J D E nB","132":"F A B"},B:{"1":"C K L G M N O P Q R U V W X Y Z a b c d e S f H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","2":"oB eB","260":"I g J D E F A B C K L G pB qB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","548":"I g J D E F A B C K L G M N O h i j k l m n o p q"},E:{"2":"tB jB","548":"I g J D E F A B C K L G uB vB wB xB kB cB dB yB zB 0B 1B"},F:{"1":"0 1 2 3 4 5 6 7 8 9 G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB dB","2":"F","548":"B C 2B 3B 4B 5B cB lB 6B"},G:{"16":"jB","548":"E 7B mB 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC"},H:{"132":"RC"},I:{"1":"H WC XC","16":"SC TC","548":"eB I UC VC mB"},J:{"548":"D A"},K:{"1":"T dB","548":"A B C cB lB"},L:{"1":"H"},M:{"1":"S"},N:{"132":"A B"},O:{"1":"YC"},P:{"1":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"1":"jC"},R:{"1":"kC"},S:{"1":"lC"}},B:2,C:"Media Queries: resolution feature"};
