module.exports={A:{A:{"132":"J D E F A B nB"},B:{"1":"C K L G M N O P Q R U V W X Y Z a b c d e S f H"},C:{"1":"3 4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","2":"oB eB I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x pB qB","322":"0 1 2 y z"},D:{"1":"AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","2":"I g J","16":"D","33":"0 1 2 3 4 5 6 7 8 9 E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z"},E:{"1":"B C K L G cB dB yB zB 0B 1B","2":"I tB jB","16":"g","33":"J D E F A uB vB wB xB kB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","2":"F B C 2B 3B 4B 5B cB lB 6B dB","33":"G M N O h i j k l m n o p q r s t u v w"},G:{"1":"GC HC IC JC KC LC MC NC OC PC QC","16":"jB 7B mB","33":"E 8B 9B AC BC CC DC EC FC"},H:{"2":"RC"},I:{"1":"H","2":"SC TC UC","33":"eB I VC mB WC XC"},J:{"33":"D A"},K:{"1":"T","2":"A B C cB lB dB"},L:{"1":"H"},M:{"1":"S"},N:{"36":"A B"},O:{"1":"YC"},P:{"1":"ZC aC bC cC dC kB eC fC gC hC iC","33":"I"},Q:{"1":"jC"},R:{"1":"kC"},S:{"1":"lC"}},B:4,C:"CSS writing-mode property"};
