module.exports={A:{A:{"1":"B","16":"nB","132":"J D E F A"},B:{"1":"C K L G M N O P Q R U V W X Y Z a b c d e S f H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","132":"oB eB I g J D E F A B C K L G M N O h i j k l m n o p q pB qB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","132":"I g J D E F A B C K L G M N O h i j k l"},E:{"1":"A B C K L G kB cB dB yB zB 0B 1B","132":"I g J D E F tB jB uB vB wB xB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","16":"F B C 2B 3B 4B 5B cB lB 6B","132":"dB"},G:{"1":"EC FC GC HC IC JC KC LC MC NC OC PC QC","132":"E jB 7B mB 8B 9B AC BC CC DC"},H:{"132":"RC"},I:{"1":"H WC XC","132":"eB I SC TC UC VC mB"},J:{"132":"D A"},K:{"1":"T","16":"A B C cB lB","132":"dB"},L:{"1":"H"},M:{"1":"S"},N:{"1":"B","132":"A"},O:{"1":"YC"},P:{"1":"ZC aC bC cC dC kB eC fC gC hC iC","132":"I"},Q:{"1":"jC"},R:{"1":"kC"},S:{"4":"lC"}},B:6,C:"localeCompare()"};
