module.exports={A:{A:{"2":"J D E F A B nB"},B:{"1":"N O","2":"C K L G M","257":"P Q R U V W X Y Z a b c d e S f H"},C:{"2":"0 1 2 3 4 5 oB eB I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z pB qB","257":"6 8 9 AB BB CB DB FB GB HB IB JB KB fB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","1281":"7 EB LB"},D:{"2":"0 1 2 3 4 5 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z","257":"CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","388":"6 7 8 9 AB BB"},E:{"2":"I g J D E F tB jB uB vB wB","514":"A B C K L G xB kB cB dB yB zB 0B","2114":"1B"},F:{"2":"F B C G M N O h i j k l m n o p q r s t u v w x y 2B 3B 4B 5B cB lB 6B dB","16":"0 1 2 3 z","257":"4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB"},G:{"2":"E jB 7B mB 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC"},H:{"2":"RC"},I:{"2":"eB I H SC TC UC VC mB WC XC"},J:{"2":"D A"},K:{"1":"T","2":"A B C cB lB dB"},L:{"1":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"1":"YC"},P:{"1":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"1":"jC"},R:{"2":"kC"},S:{"257":"lC"}},B:5,C:"Push API"};
