module.exports={A:{A:{"2":"J D E F A B nB"},B:{"1":"P Q R U V W X Y Z a b c d e S f H","2":"C K","322":"L","8196":"G M N O"},C:{"2":"0 1 2 3 4 5 6 7 8 9 oB eB I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB pB qB","4162":"HB IB JB KB fB LB gB MB NB T OB","16452":"PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB"},D:{"1":"bB P Q R U V W X Y Z a b c d e S f H iB rB sB","2":"0 1 2 3 4 5 6 7 8 9 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB","194":"FB GB HB IB JB KB","1090":"fB LB","8196":"gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB"},E:{"1":"K L G dB yB zB 0B 1B","2":"I g J D E F tB jB uB vB wB xB","514":"A B kB","8196":"C cB"},F:{"1":"PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","2":"0 1 F B C G M N O h i j k l m n o p q r s t u v w x y z 2B 3B 4B 5B cB lB 6B dB","194":"2 3 4 5 6 7 8 9","8196":"AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB"},G:{"1":"JC KC LC MC NC OC PC QC","2":"E jB 7B mB 8B 9B AC BC CC DC","514":"EC FC GC","8196":"HC IC"},H:{"2":"RC"},I:{"2":"eB I H SC TC UC VC mB WC XC"},J:{"2":"D A"},K:{"1":"T","2":"A B C cB lB dB"},L:{"2049":"H"},M:{"2":"S"},N:{"2":"A B"},O:{"2":"YC"},P:{"1":"fC gC hC iC","2":"I","8196":"ZC aC bC cC dC kB eC"},Q:{"8196":"jC"},R:{"2":"kC"},S:{"2":"lC"}},B:4,C:"Payment Request API"};
