module.exports={A:{A:{"1":"B","4":"J D E F A nB"},B:{"1":"C K L G M","129":"N O P Q R U V W X Y Z a b c d e S f H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB","4":"oB eB I g pB qB","129":"DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB"},D:{"1":"7 8 9 AB BB CB DB EB FB GB","4":"I g J","129":"0 1 2 3 4 5 6 D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB"},E:{"4":"I g tB jB","129":"J D E F A B C K L G uB vB wB xB kB cB dB yB zB 0B 1B"},F:{"1":"0 1 2 3 C u v w x y z cB lB 6B dB","4":"F B 2B 3B 4B 5B","129":"4 5 6 7 8 9 G M N O h i j k l m n o p q r s t AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB"},G:{"4":"jB 7B mB","129":"E 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC"},H:{"4":"RC"},I:{"4":"SC TC UC","129":"eB I H VC mB WC XC"},J:{"129":"D A"},K:{"1":"C cB lB dB","4":"A B","129":"T"},L:{"129":"H"},M:{"129":"S"},N:{"1":"B","4":"A"},O:{"129":"YC"},P:{"129":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"1":"jC"},R:{"129":"kC"},S:{"1":"lC"}},B:1,C:"dataset & data-* attributes"};
