module.exports={A:{A:{"1":"B","2":"J D E F A nB"},B:{"1":"L G M N O P Q R U V W X Y Z a b c d e S f H","129":"C K"},C:{"1":"CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","2":"oB eB","260":"0 1 2 3 4 5 6 7 8 9 G M N O h i j k l m n o p q r s t u v w x y z AB BB","804":"I g J D E F A B C K L pB qB"},D:{"1":"IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","260":"DB EB FB GB HB","388":"0 1 2 3 4 5 6 7 8 9 s t u v w x y z AB BB CB","1412":"G M N O h i j k l m n o p q r","1956":"I g J D E F A B C K L"},E:{"129":"A B C K L G xB kB cB dB yB zB 0B 1B","1412":"J D E F vB wB","1956":"I g tB jB uB"},F:{"1":"5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","2":"F 2B 3B","260":"0 1 2 3 4","388":"G M N O h i j k l m n o p q r s t u v w x y z","1796":"4B 5B","1828":"B C cB lB 6B dB"},G:{"129":"DC EC FC GC HC IC JC KC LC MC NC OC PC QC","1412":"E 9B AC BC CC","1956":"jB 7B mB 8B"},H:{"1828":"RC"},I:{"1":"H","388":"WC XC","1956":"eB I SC TC UC VC mB"},J:{"1412":"A","1924":"D"},K:{"1":"T","2":"A","1828":"B C cB lB dB"},L:{"1":"H"},M:{"1":"S"},N:{"1":"B","2":"A"},O:{"388":"YC"},P:{"1":"bC cC dC kB eC fC gC hC iC","260":"ZC aC","388":"I"},Q:{"260":"jC"},R:{"260":"kC"},S:{"260":"lC"}},B:4,C:"CSS3 Border images"};
