module.exports={A:{A:{"2":"J D E F A nB","2052":"B"},B:{"1":"C K L G M N O P Q R U V W X Y Z a b c d e S f H"},C:{"1":"6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","194":"0 1 2 3 4 5 oB eB I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z pB qB"},D:{"1":"BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","2":"I g J D E F A B C K L G M N O","322":"0 1 2 h i j k l m n o p q r s t u v w x y z","516":"3 4 5 6 7 8 9 AB"},E:{"1":"B C K L G cB dB yB zB 0B 1B","2":"I g J D E F tB jB uB vB wB xB","1028":"A kB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","2":"F B C 2B 3B 4B 5B cB lB 6B dB","322":"G M N O h i j k l m n o p","516":"q r s t u v w x"},G:{"1":"GC HC IC JC KC LC MC NC OC PC QC","2":"E jB 7B mB 8B 9B AC BC CC DC","1028":"EC FC"},H:{"2":"RC"},I:{"1":"H","2":"eB I SC TC UC VC mB WC XC"},J:{"2":"D A"},K:{"1":"T","2":"A B C cB lB dB"},L:{"1":"H"},M:{"1":"S"},N:{"1":"B","2":"A"},O:{"1":"YC"},P:{"1":"ZC aC bC cC dC kB eC fC gC hC iC","516":"I"},Q:{"1":"jC"},R:{"516":"kC"},S:{"1":"lC"}},B:6,C:"let"};
