module.exports={A:{A:{"1":"F A B","16":"nB","260":"J D E"},B:{"1":"C K L G M N O P Q R U V W X Y Z a b c d e S f H"},C:{"1":"EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","132":"0 1 2 3 4 oB eB I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z pB qB","2180":"5 6 7 8 9 AB BB CB DB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","16":"I g J D E F A B C K L"},E:{"1":"J D E F A B C K L G uB vB wB xB kB cB dB yB zB 0B 1B","16":"I g tB jB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","132":"F B C 2B 3B 4B 5B cB lB 6B dB"},G:{"16":"mB","132":"jB 7B","516":"E 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC"},H:{"2":"RC"},I:{"1":"H WC XC","16":"eB I SC TC UC VC","1025":"mB"},J:{"1":"A","16":"D"},K:{"1":"T","16":"A B C cB lB","132":"dB"},L:{"1":"H"},M:{"1":"S"},N:{"1":"B","16":"A"},O:{"1025":"YC"},P:{"1":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"1":"jC"},R:{"1":"kC"},S:{"2180":"lC"}},B:5,C:"Selection API"};
