module.exports={A:{A:{"4":"J D E F A B nB"},B:{"4":"C K L G M N O P Q R U V W X Y Z a b c d e S f H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","8":"oB eB I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z pB qB"},D:{"4":"0 1 2 3 4 5 6 7 8 9 g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","8":"I"},E:{"4":"g J D E F A B C K L G uB vB wB xB kB cB dB yB zB 0B 1B","8":"I tB jB"},F:{"4":"0 1 2 3 4 5 6 7 8 9 G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","8":"F B C 2B 3B 4B 5B cB lB 6B dB"},G:{"4":"E 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC","8":"jB 7B mB"},H:{"8":"RC"},I:{"4":"eB I H VC mB WC XC","8":"SC TC UC"},J:{"4":"A","8":"D"},K:{"4":"T","8":"A B C cB lB dB"},L:{"4":"H"},M:{"1":"S"},N:{"4":"A B"},O:{"4":"YC"},P:{"4":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"4":"jC"},R:{"4":"kC"},S:{"1":"lC"}},B:1,C:"Ruby annotation"};
