module.exports={A:{A:{"2":"J D E F A B nB"},B:{"1":"P Q R U V W X Y Z a b c d e S f H","2":"C K L G M N O"},C:{"1":"c d e S f H iB","2":"oB eB pB qB","33":"FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b","164":"0 1 2 3 4 5 6 7 8 9 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB"},D:{"1":"4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","2":"I g J D E F A B C K L G M N O h i","132":"0 1 2 3 j k l m n o p q r s t u v w x y z"},E:{"1":"L G yB zB 0B 1B","2":"I g J tB jB uB","132":"D E F A B C K vB wB xB kB cB dB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","2":"F 2B 3B 4B","132":"G M N O h i j k l m n o p q","164":"B C 5B cB lB 6B dB"},G:{"1":"NC OC PC QC","2":"jB 7B mB 8B 9B","132":"E AC BC CC DC EC FC GC HC IC JC KC LC MC"},H:{"164":"RC"},I:{"1":"H","2":"eB I SC TC UC VC mB","132":"WC XC"},J:{"132":"D A"},K:{"1":"T","2":"A","164":"B C cB lB dB"},L:{"1":"H"},M:{"33":"S"},N:{"2":"A B"},O:{"1":"YC"},P:{"1":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"1":"jC"},R:{"1":"kC"},S:{"164":"lC"}},B:5,C:"CSS3 tab-size"};
