module.exports={A:{A:{"2":"F A B nB","8":"J D E"},B:{"2":"C K L G M N O","8":"P Q R U V W X Y Z a b c d e S f H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","129":"oB eB pB qB"},D:{"1":"m","8":"0 1 2 3 4 5 6 7 8 9 I g J D E F A B C K L G M N O h i j k l n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H","584":"iB rB sB"},E:{"1":"A B C K L G kB cB dB yB zB 0B 1B","260":"I g J D E F tB jB uB vB wB xB"},F:{"2":"F","4":"B C 2B 3B 4B 5B cB lB 6B dB","8":"0 1 2 3 4 5 6 7 8 9 G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB"},G:{"1":"E 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC","8":"jB 7B mB"},H:{"8":"RC"},I:{"8":"eB I H SC TC UC VC mB WC XC"},J:{"1":"A","8":"D"},K:{"8":"A B C T cB lB dB"},L:{"8":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"4":"YC"},P:{"8":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"8":"jC"},R:{"8":"kC"},S:{"1":"lC"}},B:2,C:"MathML"};
