module.exports={A:{A:{"2":"J D E nB","388":"F A B"},B:{"4":"P Q R U V W X Y Z a b c d e S f H","260":"C K L G M N O"},C:{"1":"0 1 2 3 4 5 6 7 8 9 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB pB qB","2":"oB","4":"eB"},D:{"4":"0 1 2 3 4 5 6 7 8 9 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB"},E:{"2":"tB jB","4":"I g J D E F A B C K L G uB vB wB xB kB cB dB yB zB 0B 1B"},F:{"4":"0 1 2 3 4 5 6 7 8 9 F B C G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB 2B 3B 4B 5B cB lB 6B dB"},G:{"4":"E jB 7B mB 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC"},H:{"2":"RC"},I:{"2":"eB I SC TC UC VC mB","4":"H WC XC"},J:{"1":"A","2":"D"},K:{"4":"A B C T cB lB dB"},L:{"4":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"2":"YC"},P:{"4":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"4":"jC"},R:{"4":"kC"},S:{"1":"lC"}},B:2,C:"SVG effects for HTML"};
