module.exports={A:{A:{"2":"J D E F A B nB"},B:{"1":"V W X Y Z a b c d e S f H","2":"C K L G M N O","260":"P Q R U"},C:{"1":"R hB U V W X Y Z a b c d e S f H iB","2":"oB eB I g J D E F A B C K L G M N O h i j k l m n o p q r s t u pB qB","260":"fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB","516":"9 AB BB CB DB EB FB GB HB IB JB KB","580":"0 1 2 3 4 5 6 7 8 v w x y z","2049":"YB ZB aB bB P Q"},D:{"1":"V W X Y Z a b c d e S f H iB rB sB","2":"I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x","132":"0 y z","260":"1 2 3 4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U"},E:{"1":"G 0B 1B","2":"I g J D E F A tB jB uB vB wB xB kB","1090":"B C K cB dB","2049":"L yB zB"},F:{"1":"UB VB WB XB YB ZB aB bB P Q R hB","2":"F B C G M N O h i j k 2B 3B 4B 5B cB lB 6B dB","132":"l m n","260":"0 1 2 3 4 5 6 7 8 9 o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB"},G:{"2":"E jB 7B mB 8B 9B AC BC CC DC EC FC","1090":"GC HC IC JC KC LC MC","2049":"NC OC PC QC"},H:{"2":"RC"},I:{"1":"H","2":"eB I SC TC UC VC mB WC XC"},J:{"2":"D A"},K:{"1":"T","2":"A B C cB lB dB"},L:{"1":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"260":"YC"},P:{"260":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"260":"jC"},R:{"260":"kC"},S:{"516":"lC"}},B:5,C:"Web Animations API"};
