module.exports={A:{A:{"2":"J D E nB","520":"F A B"},B:{"1":"P Q R U V W X Y Z a b c d e S f H","8":"C K","388":"L G M N O"},C:{"1":"0 1 2 3 4 5 6 7 8 9 q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","2":"oB eB pB qB","132":"I g J D E F A B C K L G M N O h i j k l m n o p"},D:{"1":"0 1 2 3 4 5 6 7 8 9 n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","2":"I g","132":"J D E F A B C K L G M N O h i j k l m"},E:{"2":"tB","8":"I g jB uB","520":"J D E F A B C vB wB xB kB cB","1028":"K dB yB","7172":"L","8196":"G zB 0B 1B"},F:{"1":"0 1 2 3 4 5 6 7 8 9 M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","2":"F 2B 3B 4B","132":"B C G 5B cB lB 6B dB"},G:{"2":"E jB 7B mB 8B 9B AC BC CC DC EC FC GC HC IC","1028":"JC KC LC MC NC","3076":"OC PC QC"},H:{"2":"RC"},I:{"1":"H","2":"SC TC","132":"eB I UC VC mB WC XC"},J:{"2":"D A"},K:{"1":"T","2":"A B C cB lB dB"},L:{"1":"H"},M:{"1":"S"},N:{"8":"A B"},O:{"1":"YC"},P:{"1":"ZC aC bC cC dC kB eC fC gC hC iC","132":"I"},Q:{"1":"jC"},R:{"1":"kC"},S:{"1":"lC"}},B:6,C:"WebM video format"};
