module.exports={A:{A:{"2":"nB","8":"J D E F","260":"A B"},B:{"1":"P Q R U V W X Y Z a b c d e S f H","260":"C K L G","1284":"M N O"},C:{"8":"oB eB pB qB","4612":"0 1 2 3 4 5 6 7 8 9 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB"},D:{"1":"SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","8":"I g J D E F A B C K L G M N O h","132":"0 1 2 3 4 5 6 7 8 9 i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB"},E:{"1":"K L G dB yB zB 0B 1B","8":"I g J D E F A B C tB jB uB vB wB xB kB cB"},F:{"1":"F B C T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB 2B 3B 4B 5B cB lB 6B dB","132":"0 1 2 3 4 5 6 7 8 9 G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB"},G:{"8":"E jB 7B mB 8B 9B AC BC CC DC EC FC GC HC IC","2049":"JC KC LC MC NC OC PC QC"},H:{"2":"RC"},I:{"1":"H XC","8":"eB I SC TC UC VC mB WC"},J:{"1":"A","8":"D"},K:{"1":"A B C T cB lB dB"},L:{"1":"H"},M:{"516":"S"},N:{"8":"A B"},O:{"8":"YC"},P:{"1":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"132":"jC"},R:{"1":"kC"},S:{"2":"lC"}},B:1,C:"Datalist element"};
