module.exports={A:{A:{"132":"J D E F A B nB"},B:{"132":"C K L G M N O P Q R U V W X Y Z a b c d e S f H"},C:{"132":"0 1 2 3 4 5 6 7 8 9 oB eB I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB pB qB"},D:{"132":"0 1 2 3 4 5 6 7 8 9 I g t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","388":"J D E F A B C K L G M N O h i j k l m n o p q r s"},E:{"132":"I g J D E F A B C K L G tB jB uB vB wB xB kB cB dB yB zB 0B 1B"},F:{"132":"0 1 2 3 4 5 6 7 8 9 F B C G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB 2B 3B 4B 5B cB lB 6B dB"},G:{"132":"E jB 7B mB 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC"},H:{"132":"RC"},I:{"132":"eB I H SC TC UC VC mB WC XC"},J:{"132":"D A"},K:{"132":"A B C T cB lB dB"},L:{"132":"H"},M:{"132":"S"},N:{"132":"A B"},O:{"132":"YC"},P:{"132":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"132":"jC"},R:{"132":"kC"},S:{"132":"lC"}},B:6,C:"DNSSEC and DANE"};
