module.exports={A:{A:{"2":"J D E F A nB","548":"B"},B:{"1":"P Q R U V W X Y Z a b c d e S f H","516":"C K L G M N O"},C:{"1":"T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","2":"oB eB I g J D E F pB qB","676":"0 1 2 3 4 5 6 7 8 A B C K L G M N O h i j k l m n o p q r s t u v w x y z","1700":"9 AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB"},D:{"1":"UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","2":"I g J D E F A B C K L","676":"G M N O h","804":"0 1 2 3 4 5 6 7 8 9 i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB"},E:{"2":"I g tB jB","676":"uB","804":"J D E F A B C K L G vB wB xB kB cB dB yB zB 0B 1B"},F:{"1":"T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB dB","2":"F B C 2B 3B 4B 5B cB lB 6B","804":"0 1 2 3 4 5 6 7 8 9 G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB"},G:{"2":"E jB 7B mB 8B 9B AC BC CC DC EC FC GC HC QC","2052":"IC JC KC LC MC NC OC PC"},H:{"2":"RC"},I:{"2":"eB I H SC TC UC VC mB WC XC"},J:{"2":"D","292":"A"},K:{"2":"A B C T cB lB dB"},L:{"804":"H"},M:{"1":"S"},N:{"2":"A","548":"B"},O:{"804":"YC"},P:{"1":"kB eC fC gC hC iC","804":"I ZC aC bC cC dC"},Q:{"804":"jC"},R:{"804":"kC"},S:{"1":"lC"}},B:1,C:"Full Screen API"};
