module.exports={A:{A:{"388":"A B","900":"J D E F nB"},B:{"388":"C K L G M N O","900":"P Q R U V W X Y Z a b c d e S f H"},C:{"772":"OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","900":"0 1 2 3 4 5 6 7 8 9 oB eB I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T pB qB"},D:{"900":"0 1 2 3 4 5 6 7 8 9 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB"},E:{"772":"A","900":"I g J D E F B C K L G tB jB uB vB wB xB kB cB dB yB zB 0B 1B"},F:{"16":"F 2B","129":"B C 3B 4B 5B cB lB 6B dB","900":"0 1 2 3 4 5 6 7 8 9 G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB"},G:{"900":"E jB 7B mB 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC"},H:{"129":"RC"},I:{"900":"eB I H SC TC UC VC mB WC XC"},J:{"900":"D A"},K:{"129":"A B C cB lB dB","900":"T"},L:{"900":"H"},M:{"900":"S"},N:{"388":"A B"},O:{"900":"YC"},P:{"900":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"900":"jC"},R:{"900":"kC"},S:{"900":"lC"}},B:2,C:"CSS page-break properties"};
