module.exports={A:{A:{"388":"J D E F A B nB"},B:{"1":"b c d e S f H","260":"P Q R U V W X Y Z a","388":"C K L G M N O"},C:{"1":"R hB U V W X Y Z a b c d e S f H iB","260":"gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q","388":"0 1 2 3 4 5 6 7 8 9 oB eB I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB pB qB"},D:{"1":"b c d e S f H iB rB sB","260":"RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a","388":"0 1 2 3 4 5 6 7 8 9 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB"},E:{"1":"1B","260":"L G yB zB 0B","388":"I g J D E F A B C K tB jB uB vB wB xB kB cB dB"},F:{"260":"HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","388":"0 1 2 3 4 5 6 7 8 9 F B C G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB 2B 3B 4B 5B cB lB 6B dB"},G:{"260":"NC OC PC QC","388":"E jB 7B mB 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC"},H:{"388":"RC"},I:{"1":"H","388":"eB I SC TC UC VC mB WC XC"},J:{"388":"D A"},K:{"1":"T","388":"A B C cB lB dB"},L:{"1":"H"},M:{"1":"S"},N:{"388":"A B"},O:{"388":"YC"},P:{"1":"iC","388":"I ZC aC bC cC dC kB eC fC gC hC"},Q:{"388":"jC"},R:{"388":"kC"},S:{"388":"lC"}},B:5,C:"CSS overflow property"};
