module.exports={A:{A:{"2":"J D E F A B nB"},B:{"1":"P Q R U V W X Y Z a b c d e S f H","2":"C K","132":"L G M N O"},C:{"1":"AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","2":"oB eB I g J D E F A B C K L G M N O h i j k l m n o p q r s pB qB","132":"0 1 2 3 4 5 6 7 8 9 t u v w x y z"},D:{"1":"RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","2":"I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x","132":"0 1 2 3 4 5 6 7 8 9 y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB"},E:{"1":"A B C K L G xB kB cB dB yB zB 0B 1B","2":"I g J D tB jB uB vB","132":"E F wB"},F:{"1":"HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","2":"F B C G M N O h i j k 2B 3B 4B 5B cB lB 6B dB","132":"0 1 2 3 4 5 6 7 8 9 l m n o p q r s t u v w x y z AB BB CB DB EB FB GB"},G:{"1":"CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC","2":"jB 7B mB 8B 9B AC","16":"E","132":"BC"},H:{"2":"RC"},I:{"1":"H","2":"eB I SC TC UC VC mB WC XC"},J:{"1":"A","2":"D"},K:{"1":"T","2":"A B C cB lB dB"},L:{"1":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"132":"YC"},P:{"1":"kB eC fC gC hC iC","132":"I ZC aC bC cC dC"},Q:{"132":"jC"},R:{"132":"kC"},S:{"1":"lC"}},B:1,C:"Path2D"};
