module.exports={A:{A:{"2":"J D E F nB","130":"A B"},B:{"130":"C K L G M N O P Q R U V W X Y Z a b c d e S f H"},C:{"1":"0 1 2 3 4 5 6 7 8 9 w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","2":"oB eB pB qB","130":"I g J D E F A B C K L G M N O h i j k l","322":"m n o p q r s t u v"},D:{"2":"I g J D E F A B C K L G","130":"0 1 2 3 4 5 6 7 8 9 M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB"},E:{"1":"A B C K L G xB kB cB dB yB zB 0B 1B","2":"D E F tB jB vB wB","130":"I g J uB"},F:{"2":"F B C 2B 3B 4B 5B cB lB 6B dB","130":"0 1 2 3 4 5 6 7 8 9 G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB"},G:{"1":"DC EC FC GC HC IC JC KC LC MC NC OC PC QC","2":"E jB AC BC CC","130":"7B mB 8B 9B"},H:{"2":"RC"},I:{"2":"eB I SC TC UC VC mB","130":"H WC XC"},J:{"2":"D","130":"A"},K:{"2":"A B C cB lB dB","130":"T"},L:{"130":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"130":"YC"},P:{"130":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"130":"jC"},R:{"130":"kC"},S:{"1":"lC"}},B:5,C:"CSS font-variant-alternates"};
