module.exports={A:{A:{"2":"J D E F nB","900":"A B"},B:{"1":"N O P Q R U V W X Y Z a b c d e S f H","388":"L G M","900":"C K"},C:{"1":"DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","2":"oB eB pB qB","260":"BB CB","388":"0 1 2 3 4 5 6 7 8 9 r s t u v w x y z AB","900":"I g J D E F A B C K L G M N O h i j k l m n o p q"},D:{"1":"2 3 4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","16":"I g J D E F A B C K L","388":"0 1 n o p q r s t u v w x y z","900":"G M N O h i j k l m"},E:{"1":"A B C K L G kB cB dB yB zB 0B 1B","16":"I g tB jB","388":"E F wB xB","900":"J D uB vB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","16":"F B 2B 3B 4B 5B cB lB","388":"G M N O h i j k l m n o","900":"C 6B dB"},G:{"1":"EC FC GC HC IC JC KC LC MC NC OC PC QC","16":"jB 7B mB","388":"E AC BC CC DC","900":"8B 9B"},H:{"2":"RC"},I:{"1":"H","16":"eB SC TC UC","388":"WC XC","900":"I VC mB"},J:{"16":"D","388":"A"},K:{"1":"T","16":"A B cB lB","900":"C dB"},L:{"1":"H"},M:{"1":"S"},N:{"900":"A B"},O:{"1":"YC"},P:{"1":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"1":"jC"},R:{"1":"kC"},S:{"388":"lC"}},B:1,C:"Constraint Validation API"};
