module.exports={A:{A:{"1":"J D E F A nB","132":"B"},B:{"132":"C K L G M N O","260":"P Q R U V W X Y Z a b c d e S f H"},C:{"1":"oB eB I g J D E F A B C K L G M N O h i j k l m n o p q r pB qB","516":"0 1 2 3 4 5 6 7 8 9 s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB"},D:{"1":"N O h i j k l m n o","2":"I g J D E F A B C K L G M","132":"0 1 2 p q r s t u v w x y z","260":"3 4 5 6 7 8 9 AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB"},E:{"1":"J uB vB","2":"I g tB jB","2052":"D E F A B C K L G wB xB kB cB dB yB zB 0B 1B"},F:{"1":"0 1 2 3 4 5 6 7 8 9 F B C G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB 2B 3B 4B 5B cB lB 6B dB"},G:{"2":"jB 7B mB","1025":"E 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC"},H:{"1025":"RC"},I:{"1":"eB I H SC TC UC VC mB WC XC"},J:{"1":"D A"},K:{"1":"A B C T cB lB dB"},L:{"1":"H"},M:{"1":"S"},N:{"2052":"A B"},O:{"1025":"YC"},P:{"1":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"260":"jC"},R:{"1":"kC"},S:{"516":"lC"}},B:1,C:"autocomplete attribute: on & off values"};
