module.exports={A:{A:{"2":"J D E F A nB","132":"B"},B:{"1":"C K L G M N O","4":"P Q R U V W X Y Z a b c d e S f H"},C:{"2":"oB eB pB","4":"0 1 2 3 4 5 6 7 8 9 J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","8":"I g qB"},D:{"2":"I g J","4":"0 1 2 3 4 5 6 7 8 9 D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB"},E:{"2":"I g J D E F A B C K L G tB jB uB vB wB xB kB cB dB yB zB 0B 1B"},F:{"2":"F B C 2B 3B 4B 5B cB lB 6B dB","4":"0 1 2 3 4 5 6 7 8 9 G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB"},G:{"2":"jB 7B","4":"E mB 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC"},H:{"2":"RC"},I:{"2":"SC TC UC","4":"eB I H VC mB WC XC"},J:{"2":"D","4":"A"},K:{"1":"C dB","2":"A B cB lB","4":"T"},L:{"4":"H"},M:{"4":"S"},N:{"1":"B","2":"A"},O:{"4":"YC"},P:{"4":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"4":"jC"},R:{"4":"kC"},S:{"4":"lC"}},B:4,C:"DeviceOrientation & DeviceMotion events"};
