module.exports={A:{A:{"2":"J D E nB","260":"F A B"},B:{"132":"P Q R U V W X Y Z a b c d e S f H","260":"C K L G M N O"},C:{"2":"oB eB I g pB qB","260":"0 1 2 3 4 5 6 7 8 9 J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB"},D:{"16":"I g J D E F A B C K L","132":"0 1 2 3 4 5 6 7 8 9 G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB"},E:{"16":"tB jB","132":"I g J D E F A B C K L G uB vB wB xB kB cB dB yB zB 0B 1B"},F:{"1":"C 6B dB","2":"F 2B 3B 4B 5B","16":"B cB lB","132":"0 1 2 3 4 5 6 7 8 9 G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB"},G:{"16":"jB 7B","132":"E mB 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC"},H:{"2":"RC"},I:{"16":"SC TC","132":"eB I H UC VC mB WC XC"},J:{"132":"D A"},K:{"1":"C dB","2":"A","16":"B cB lB","132":"T"},L:{"132":"H"},M:{"260":"S"},N:{"260":"A B"},O:{"132":"YC"},P:{"132":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"132":"jC"},R:{"132":"kC"},S:{"260":"lC"}},B:5,C:"Mutation events"};
