module.exports={A:{A:{"2":"J D E F A B nB"},B:{"1":"O P Q R U V W X Y Z a b c d e S f H","2":"C K L G M N"},C:{"1":"OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB U V W X Y Z a b c d e S f H iB","2":"oB eB pB qB","8":"0 1 2 3 4 5 6 7 8 9 I g J D E F A B C K L G M N O h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T"},D:{"1":"0 1 2 3 4 5 6 7 8 9 u v w x y z AB BB CB DB EB FB GB HB IB JB KB fB LB gB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R U V W X Y Z a b c d e S f H iB rB sB","2":"I g","8":"J D E","132":"F A B C K L G M N O h i j k","260":"l m n o p q r s t"},E:{"2":"I g J D E F A B C K tB jB uB vB wB xB kB cB dB yB","516":"L G zB 0B 1B"},F:{"1":"0 1 2 3 4 5 6 7 8 9 h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB GB HB IB JB KB LB MB NB T OB PB QB RB SB TB UB VB WB XB YB ZB aB bB P Q R hB","2":"F 2B 3B 4B","8":"B 5B","132":"cB lB 6B","260":"C G M N O dB"},G:{"1":"OC PC QC","2":"E jB 7B mB 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC"},H:{"1":"RC"},I:{"1":"H mB WC XC","2":"eB SC TC UC","132":"I VC"},J:{"2":"D A"},K:{"1":"C T cB lB dB","2":"A","132":"B"},L:{"1":"H"},M:{"1":"S"},N:{"2":"A B"},O:{"1":"YC"},P:{"1":"I ZC aC bC cC dC kB eC fC gC hC iC"},Q:{"1":"jC"},R:{"1":"kC"},S:{"8":"lC"}},B:7,C:"WebP image format"};
